% S Adhikari: June 2006, Bristol
% Hom_EXP is Nsamp x Nfreq  x Nchan array of measured transfer functions
% Nsamp: number of samples, 100
% Nfreq: number of frequency points
% Nchan: number of output channels = 3 
% Hom_EXP_baseline is the FRF of the baseline model (ie, no attached masses)
% f_max is maximum frequency (8192 Hz)- [need to change it later]
% omega is the array of the driving frequency in rad/s,  
%                           omega=(0:1:f_max).*(2*pi);.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all; clear all;
disp('Loading and plotting experimental data');
load PlateEXPdata;  load OscillatorCoordinates;

fsize=14;fname='times';
y_min=-40;y_max=60;
f_max=4.0e3; % Maximum freq in Hz (change f_max to fit in the plots)
f_low=1.0e3; % Low freq vibration limit (border between low and mid)
f_mid=2.5e3; % Low freq vibration limit (border between mid and high)

[jk,id_EXP,omega_EXP]=find( omega < f_max*2*pi);
omega_EXP=omega(id_EXP);
n_EXP=length(omega_EXP);

nplots=6;

% Calculate statistics
for jplot=1:nplots   
    stat_ABS_EXP(1,:,jplot)=20*log10(mean(abs(Hom_EXP(:,1:n_EXP,jplot))));
    stat_ABS_EXP(2,:,jplot)=20*log10(prctile(abs(Hom_EXP(:,1:n_EXP,jplot)),5));
    stat_ABS_EXP(3,:,jplot)=20*log10(prctile(abs(Hom_EXP(:,1:n_EXP,jplot)),95));
    stat_ABS_EXP(4,:,jplot)=20*log10(std(abs(Hom_EXP(:,1:n_EXP,jplot))));
    stat_ABS_EXP(5,:,jplot)=(std(abs(Hom_EXP(:,1:n_EXP,jplot))))./(mean(abs(Hom_EXP(:,1:n_EXP,jplot))));

% Phase
    stat_PHS_EXP(1,:,jplot)=(mean(angle(-Hom_EXP(:,1:n_EXP,jplot))));
    stat_PHS_EXP(2,:,jplot)=(prctile(angle(-Hom_EXP(:,1:n_EXP,jplot)),5));
    stat_PHS_EXP(3,:,jplot)=(prctile(angle(-Hom_EXP(:,1:n_EXP,jplot)),95));
    stat_PHS_EXP(4,:,jplot)=(std(angle(-Hom_EXP(:,1:n_EXP,jplot))));
        
end

% Plot all experimental samples: absolute value
for jplot=1:nplots    
   figure(jplot);clf;hold all;
   		plot(...
   		      omega_EXP/2/pi,20*log10(abs(Hom_EXP_baseline(jplot,1:n_EXP))),'-.m',...
   		      omega_EXP/2/pi,stat_ABS_EXP(1,:,jplot),'-r', ...
   		      omega_EXP/2/pi,stat_ABS_EXP(2,:,jplot),'--b',...
   		      omega_EXP/2/pi,stat_ABS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		h2=legend('Baseline','Ensemble mean ','5% line','95% line');
   		plot(omega_EXP/2/pi,20*log10(abs(Hom_EXP(:,1:n_EXP,jplot))),'-',...
   		     'Color',[0.75 0.75 0.77],'linewidth',0.5);
   		plot(...
   		      omega_EXP/2/pi,20*log10(abs(Hom_EXP_baseline(jplot,1:n_EXP))),'-.m',...
   		      omega_EXP/2/pi,stat_ABS_EXP(1,:,jplot),'-r', ...
   		      omega_EXP/2/pi,stat_ABS_EXP(2,:,jplot),'--b',...
   		      omega_EXP/2/pi,stat_ABS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		xlabel('Frequency (Hz)','FontName',fname,'fontsize',fsize)
   		ylabel(['Log amplitude (dB) of H_{(2,' int2str(jplot) ')} (\omega)'],'FontName',fname,'fontsize',fsize)
   		ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
	 	set(h2,'Location','Best','linewidth',0.5,'FontName',fname,'FontSize',10);
        t1=axis;t2=t1;t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2);
        eval(['print -depsc PlateEXP_ABS_FRF' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 PlateEXP_ABS_FRF' num2str(jplot) '.jpeg' ]);
        hgsave(['PlateEXP_ABS_FRF' num2str(jplot) '.fig' ]);
       
        % Save Low frequency vibration
        t2(2)=f_low;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc PlateEXP_ABS_FRF_LowFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 PlateEXP_ABS_FRF_LowFreq' num2str(jplot) '.jpeg' ]);
          
        % Save Mid frequency vibration
        t2(1)=f_low;t2(2)=f_mid;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc PlateEXP_ABS_FRF_MidFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 PlateEXP_ABS_FRF_MidFreq' num2str(jplot) '.jpeg' ]);
          
        % Save High frequency vibration
        t2(1)=f_mid;t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc PlateEXP_ABS_FRF_HiFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 PlateEXP_ABS_FRF_HiFreq' num2str(jplot) '.jpeg' ]);
          
        % Get back to the actual plot
        t2(1)=t1(1);t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2);                 
end


% Plot all experimental samples: phase angle
for jplot=1:nplots    
      figure(jplot+6);clf;hold all;
        plot(...
              omega_EXP/2/pi,(angle(-Hom_EXP_baseline(jplot,1:n_EXP))),'-.r',...
              omega_EXP/2/pi,stat_PHS_EXP(1,:,jplot),'-m', ...
              omega_EXP/2/pi,stat_PHS_EXP(2,:,jplot),'--b',...
              omega_EXP/2/pi,stat_PHS_EXP(3,:,jplot),':k','linewidth',1.5);      
        h2=legend('Baseline','Ensemble mean ','5% line','95% line');
        plot(omega_EXP/2/pi,(angle(-Hom_EXP(:,1:n_EXP,jplot))),'-',...
             'Color',[0.75 0.75 0.77],'linewidth',0.5);
        plot(...
              omega_EXP/2/pi,(angle(-Hom_EXP_baseline(jplot,1:n_EXP))),'-.r',...
              omega_EXP/2/pi,stat_PHS_EXP(1,:,jplot),'-m', ...
              omega_EXP/2/pi,stat_PHS_EXP(2,:,jplot),'--b',...
              omega_EXP/2/pi,stat_PHS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		xlabel('Frequency (Hz)','FontName',fname,'fontsize',fsize)
   		ylabel(['Phase of H_{(2,' int2str(jplot) ')} (\omega)'],'FontName',fname,'fontsize',fsize)
        ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
        t1=axis;t2=t1;t2(2)=f_max;t2(3)=-4.0;t2(4)=4.0;axis(t2);
        set(h2,'Location','Best','linewidth',0.5,'FontName',fname,'FontSize',10);
        eval(['print -depsc PlateEXP_PHS_FRF' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 PlateEXP_PHS_FRF' num2str(jplot) '.jpeg' ]);
        hgsave(['PlateEXP_PHS_FRF' num2str(jplot) '.fig' ]);

        % Save Low frequency vibration
        t2(2)=f_low;axis(t2); 
        eval(['print -depsc PlateEXP_PHS_FRF_LowFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 PlateEXP_PHS_FRF_LowFreq' num2str(jplot) '.jpeg' ]);
          
        % Save Mid frequency vibration
        t2(1)=f_low;t2(2)=f_mid;axis(t2); 
        eval(['print -depsc PlateEXP_PHS_FRF_MidFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 PlateEXP_PHS_FRF_MidFreq' num2str(jplot) '.jpeg' ]);
          
        % Save High frequency vibration
        t2(1)=f_mid;t2(2)=f_max;axis(t2); 
        eval(['print -depsc PlateEXP_PHS_FRF_HiFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 PlateEXP_PHS_FRF_HiFreq' num2str(jplot) '.jpeg' ]);
          
        % Get back to the actual plot
        t2(1)=t1(1);t2(2)=f_max;axis(t2);         
end

figure(13);clf;hold all;
for j=1:100 
    a1=OscillatorCoordinates(:,:,j);
    plot3(a1(:,1),a1(:,2),j*ones(10,1),'o:', 'MarkerEdgeColor','k',...
                'MarkerFaceColor','r',...
                'MarkerSize',7);
end
    xlabel('X direction (length)','FontName',fname,'FontSize',fsize)
	ylabel('Y direction (width)','FontName',fname,'FontSize',fsize)
	zlabel('Samples','FontName',fname,'FontSize',fsize)
	ha=gca;set(ha,'linewidth',2,'FontName',fname,'FontSize',fsize);
	view(-34,12)
print -depsc PlateOscillatorPositions.eps
print -djpeg100 PlateOscillatorPositions.jpeg

